#!/bin/bash
#
# maintainer       : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# former           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# project web page : http://search.cpan.org/~grantm/XML-SAX/SAX.pm
# source           : http://search.cpan.org/CPAN/authors/id/G/GR/GRANTM/XML-SAX-0.96.tar.gz

# Source package name
NAME="XML-SAX"
# Zenwalk package name
ZENNAME="perl_XML-SAX"
# Perl package name
PERLNAME="XML::SAX"
# Package version
VERSION="0.96"
# Source code URL
SOURCE="http://search.cpan.org/CPAN/authors/id/G/GR/GRANTM/XML-SAX-$VERSION.tar.gz"
# Files that should be placed in /usr/doc/package-version/
DOCS="Changes LICENSE MANIFEST README"

CWD=`pwd`
PKG="$CWD/$NAME-install"
ARCH="i486"
BUILD="66.1"

rm -rf $PKG
mkdir -p $PKG

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$ZENNAME: perl_XML-SAX - Simple API for XML
$ZENNAME:
$ZENNAME: XML::SAX is a SAX parser access API for Perl. It includes
$ZENNAME: classes and APIs required for implementing SAX drivers, along
$ZENNAME: with a factory class for returning any SAX parser installed on
$ZENNAME: the user's system.
$ZENNAME:
$ZENNAME:
$ZENNAME:
$ZENNAME:
$ZENNAME:
END

# Check to see if source is present. If it's not, download it
rm -rf $NAME-$VERSION
if [ -f $NAME-$VERSION.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

# Unpack source
tar xvzf $NAME-$VERSION.tar.gz

# make
cd $NAME-$VERSION
perl Makefile.PL
sed -i -e 's,share/,,' Makefile		# Patch for proper mandir
sed -i -e 's,@\$(PERL),#@\$(PERL),' Makefile			# Comment out the test for ParserDetails.ini, we'll do this from the doinst.sh
# Now do make
make

# Install on temporary directory
PERL5LIB+=$PKG/usr/lib/perl5/site_perl/5.10.0/ make install DESTDIR=$PKG

# Take care of the perllocal.pod file which also exists in other packages
mv $PKG/usr/lib/perl5/5.10.0/i486-linux-thread-multi/perllocal.pod $PKG/usr/lib/perl5/5.10.0/i486-linux-thread-multi/perllocal.pod.$NAME

# Create the doinst.sh script for the perllocal.pod file and the ParserDetails.ini file
cat > $PKG/install/doinst.sh << EOF
configcat() {
  NEW="usr/lib/perl5/5.10.0/i486-linux-thread-multi/perllocal.pod.\$1"
  OLD="usr/lib/perl5/5.10.0/i486-linux-thread-multi/perllocal.pod"
  # If there's no file by that name, mv it over:
  if [ ! -r "\$OLD" ]; then
    mv "\$NEW" "\$OLD"
  elif grep "$PERLNAME|" "\$OLD" &> /dev/null ; then # don't append it twice
    rm "\$NEW" &>/dev/null
  else
    cat "\$NEW" >> "\$OLD"
    rm "\$NEW"
  fi
}
configcat $NAME

if [ -f usr/lib/perl5/site_perl/5.10.0/XML/SAX/ParserDetails.ini ]; then
	echo "ParserDetails.ini file already installed.";
else
 	perl -MXML::SAX -e "XML::SAX->add_parser(q(XML::SAX::PurePerl))->save_parsers()"
	echo "Creating ParserDetails.ini..."
fi

EOF


# Copy Docs
mkdir -p $PKG/usr/doc/$ZENNAME-$VERSION
cd $CWD/$NAME-$VERSION
cp -a $DOCS $PKG/usr/doc/$ZENNAME-$VERSION

# Compress the man page(s)
find $PKG/usr/man -type f -exec gzip -9 {} \;

# Add the build-file in the package
mkdir -p $PKG/usr/src/$ZENNAME-$VERSION
cp "$CWD/build-$ZENNAME.sh" "$PKG/usr/src/$ZENNAME-$VERSION/build-$ZENNAME.sh"
chmod a+x "$PKG/usr/src/$ZENNAME-$VERSION/build-$ZENNAME.sh"

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Make the package
makepkg -l y -c n $CWD/$ZENNAME-$VERSION-$ARCH-$BUILD.txz

# Calculate md5sum
cd $CWD/
md5sum $ZENNAME-$VERSION-$ARCH-$BUILD.txz > $ZENNAME-$VERSION-$ARCH-$BUILD.md5

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$NAME-$VERSION
rm -rf $PKG

cat > $ZENNAME-$VERSION-$ARCH-$BUILD.src << EOF
http://pnboy.pinguix.com/gapan/$ZENNAME/build-$ZENNAME.sh
http://search.cpan.org/CPAN/authors/id/G/GR/GRANTM/XML-SAX-$VERSION.tar.gz
EOF
